@@ -5,7 +5,7 @@ void decrypt_file(FILE* ifp, FILE* ofp, int algo)
 {
     BYTE block[4 * 4];
     long int fsize = 0;
-    int i, writesize = 0, size = 0;
+    int size = 0;
 
     size = fread(&fsize, sizeof(long int), 1, ifp);
     if (size <= 0)
