@@ -1,4 +1,6 @@
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include "get_encryption_password.h"
 #include "read_pass.h"
 #include "mem.h"
