@@ -1,7 +1,7 @@
 #ifndef _ncrypt_h_
 #define _ncrypt_h_
 /*  ncrypt.h  - adapted from several aes.h files for the algo's */
-/*  $Id: ncrypt.h,v 1.3 2004/03/17 05:02:56 s-nomad Exp $ */
+/*  $Id: ncrypt.h,v 1.4 2004/08/25 20:32:55 s-nomad Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -57,6 +57,7 @@
 #define OUTPUT_WHITEN  ( INPUT_WHITEN + BLOCK_SIZE/32)
 #define ROUND_SUBKEYS  (OUTPUT_WHITEN + BLOCK_SIZE/32) /* use 2 * (# rounds) */
 #define TOTAL_SUBKEYS  (ROUND_SUBKEYS + 2*MAX_ROUNDS)
+#define MAX_LINE      256
 
 typedef unsigned char BYTE;
 typedef unsigned long DWORD;            /* 32-bit unsigned quantity */
@@ -150,6 +151,8 @@ struct ncrypt
 {
   int verbose ; /* Whether verbose was given.  */
   int algo ;
+  int key ; /* whether password given on command line or not */
+  int pfile ; /* whether password given in a text file */
   char **ifiles ;	/* multiple input files */
   unsigned ifiles_cnt ;	/* number of multiple input files */
 } ;
